@@ -21,7 +21,7 @@
 
 #include <QtCore/qplugin.h>
 
-#include <QTime>
+#include <QElapsedTimer>
 
 #include <qstringlist.h>
 #include <gcrypt.h>
@@ -31,12 +31,12 @@ namespace gcryptQCAPlugin {
 
 #include "pkcs5.c"
 
-void check_error( const QString &label, gcry_error_t err )
+void check_error( const char *label, gcry_error_t err )
 {
     // we ignore the case where it is not an error, and
     // we also don't flag weak keys.
     if ( ( GPG_ERR_NO_ERROR != err ) && ( GPG_ERR_WEAK_KEY  != gpg_err_code(err) ) ) {
-	std::cout << "Failure (" << qPrintable(label) << "): ";
+	std::cout << "Failure (" << label << "): ";
 		std::cout << gcry_strsource(err) << "/";
 		std::cout << gcry_strerror(err) << std::endl;
     }
@@ -44,6 +44,7 @@ void check_error( const QString &label, gcry_error_t err )
 
 class gcryHashContext : public QCA::HashContext
 {
+    Q_OBJECT
 public:
     gcryHashContext(int hashAlgorithm, QCA::Provider *p, const QString &type) : QCA::HashContext(p, type)
     {
@@ -56,27 +57,27 @@ public:
 	}
     }
 
-    ~gcryHashContext()
+    ~gcryHashContext() override
     {
 	gcry_md_close( context );
     }
 
-    Context *clone() const
+    Context *clone() const override
     {
-	return new gcryHashContext(*this);
+	return new gcryHashContext(m_hashAlgorithm, provider(), type());
     }
 
-    void clear()
+    void clear() override
     {
 	gcry_md_reset( context );
     }
 
-    void update(const QCA::MemoryRegion &a)
+    void update(const QCA::MemoryRegion &a) override
     {
 	gcry_md_write( context, a.data(), a.size() );
     }
 
-    QCA::MemoryRegion final()
+    QCA::MemoryRegion final() override
     {
 	unsigned char *md;
         QCA::SecureArray a( gcry_md_get_algo_dlen( m_hashAlgorithm ) );
@@ -93,6 +94,7 @@ protected:
 
 class gcryHMACContext : public QCA::MACContext
 {
+    Q_OBJECT
 public:
     gcryHMACContext(int hashAlgorithm, QCA::Provider *p, const QString &type) : QCA::MACContext(p, type)
     {
@@ -105,19 +107,19 @@ public:
         }
     }
 
-    ~gcryHMACContext()
+    ~gcryHMACContext() override
     {
         gcry_md_close( context );
     }
 
-    void setup(const QCA::SymmetricKey &key)
+    void setup(const QCA::SymmetricKey &key) override
     {
         gcry_md_setkey( context, key.data(), key.size() );
     }
 
-    Context *clone() const
+    Context *clone() const override
     {
-        return new gcryHMACContext(*this);
+        return new gcryHMACContext(m_hashAlgorithm, provider(), type());
     }
 
     void clear()
@@ -125,17 +127,17 @@ public:
         gcry_md_reset( context );
     }
 
-    QCA::KeyLength keyLength() const
+    QCA::KeyLength keyLength() const override
     {
         return anyKeyLength();
     }
 
-    void update(const QCA::MemoryRegion &a)
+    void update(const QCA::MemoryRegion &a) override
     {
         gcry_md_write( context, a.data(), a.size() );
     }
 
-    void final( QCA::MemoryRegion *out)
+    void final( QCA::MemoryRegion *out) override
     {
         QCA::SecureArray sa( gcry_md_get_algo_dlen( m_hashAlgorithm ), 0 );
         unsigned char *md;
@@ -153,6 +155,7 @@ protected:
 
 class gcryCipherContext : public QCA::CipherContext
 {
+    Q_OBJECT
 public:
     gcryCipherContext(int algorithm, int mode, bool pad, QCA::Provider *p, const QString &type) : QCA::CipherContext(p, type)
     {
@@ -164,7 +167,7 @@ public:
     void setup(QCA::Direction dir,
 	       const QCA::SymmetricKey &key,
 	       const QCA::InitializationVector &iv,
-	       const QCA::AuthTag &tag)
+	       const QCA::AuthTag &tag) override
     {
 	Q_UNUSED(tag);
 	m_direction = dir;
@@ -185,25 +188,25 @@ public:
 	check_error( "gcry_cipher_setiv", err );
     }
 
-    Context *clone() const
+    Context *clone() const override
     {
       return new gcryCipherContext( *this );
     }
 
-    int blockSize() const
+    int blockSize() const override
     {
-	unsigned int blockSize;
-	gcry_cipher_algo_info( m_cryptoAlgorithm, GCRYCTL_GET_BLKLEN, 0, (size_t*)&blockSize );
+	size_t blockSize;
+	gcry_cipher_algo_info( m_cryptoAlgorithm, GCRYCTL_GET_BLKLEN, nullptr, &blockSize );
 	return blockSize;
     }
 
-    QCA::AuthTag tag() const
+    QCA::AuthTag tag() const override
     {
     // For future implementation
 	return QCA::AuthTag();
     }
 
-    bool update(const QCA::SecureArray &in, QCA::SecureArray *out)
+    bool update(const QCA::SecureArray &in, QCA::SecureArray *out) override
     {
         QCA::SecureArray result( in.size() );
 	if (QCA::Encode == m_direction) {
@@ -217,15 +220,15 @@ public:
 	return true;
     }
 
-    bool final(QCA::SecureArray *out)
+    bool final(QCA::SecureArray *out) override
     {
         QCA::SecureArray result;
 	if (m_pad) {
 	    result.resize( blockSize() );
 	    if (QCA::Encode == m_direction) {
-		err = gcry_cipher_encrypt( context, (unsigned char*)result.data(), result.size(), NULL, 0 );
+		err = gcry_cipher_encrypt( context, (unsigned char*)result.data(), result.size(), nullptr, 0 );
 	    } else {
-		err = gcry_cipher_decrypt( context, (unsigned char*)result.data(), result.size(), NULL, 0 );
+		err = gcry_cipher_decrypt( context, (unsigned char*)result.data(), result.size(), nullptr, 0 );
 	    }
 	    check_error( "final cipher encrypt/decrypt", err );
 	} else {
@@ -235,7 +238,7 @@ public:
 	return true;
     }
 
-    QCA::KeyLength keyLength() const
+    QCA::KeyLength keyLength() const override
     {
     switch (m_cryptoAlgorithm)
 	{
@@ -271,6 +274,7 @@ protected:
 
 class pbkdf1Context : public QCA::KDFContext
 {
+    Q_OBJECT
 public:
     pbkdf1Context(int algorithm, QCA::Provider *p, const QString &type) : QCA::KDFContext(p, type)
     {
@@ -283,18 +287,18 @@ public:
 	}
     }
 
-    ~pbkdf1Context()
+    ~pbkdf1Context() override
     {
 	gcry_md_close( context );
     }
 
-    Context *clone() const
+    Context *clone() const override
     {
-	return new pbkdf1Context( *this );
+	return new pbkdf1Context( m_hashAlgorithm, provider(), type() );
     }
 
     QCA::SymmetricKey makeKey(const QCA::SecureArray &secret, const QCA::InitializationVector &salt,
-			      unsigned int keyLength, unsigned int iterationCount)
+			      unsigned int keyLength, unsigned int iterationCount) override
     {
 	/* from RFC2898:
 	   Steps:
@@ -347,10 +351,10 @@ public:
 							  const QCA::InitializationVector &salt,
 							  unsigned int keyLength,
 							  int msecInterval,
-							  unsigned int *iterationCount)
+							  unsigned int *iterationCount) override
 	{
-		Q_ASSERT(iterationCount != NULL);
-		QTime timer;
+		Q_ASSERT(iterationCount != nullptr);
+		QElapsedTimer timer;
 
 		/*
 		   from RFC2898:
@@ -415,19 +419,20 @@ protected:
 
 class pbkdf2Context : public QCA::KDFContext
 {
+    Q_OBJECT
 public:
     pbkdf2Context(int algorithm, QCA::Provider *p, const QString &type) : QCA::KDFContext(p, type)
     {
 	m_algorithm = algorithm;
     }
 
-    Context *clone() const
+    Context *clone() const override
     {
       return new pbkdf2Context( *this );
     }
 
     QCA::SymmetricKey makeKey(const QCA::SecureArray &secret, const QCA::InitializationVector &salt,
-			 unsigned int keyLength, unsigned int iterationCount)
+			 unsigned int keyLength, unsigned int iterationCount) override
     {
 	QCA::SymmetricKey result(keyLength);
 	gcry_error_t retval = gcry_pbkdf2(m_algorithm, secret.data(), secret.size(),
@@ -445,11 +450,11 @@ public:
 							  const QCA::InitializationVector &salt,
 							  unsigned int keyLength,
 							  int msecInterval,
-							  unsigned int *iterationCount)
+							  unsigned int *iterationCount) override
 	{
-		Q_ASSERT(iterationCount != NULL);
+		Q_ASSERT(iterationCount != nullptr);
 		QCA::SymmetricKey result(keyLength);
-		QTime timer;
+		QElapsedTimer timer;
 
 		*iterationCount = 0;
 		timer.start();
@@ -507,7 +512,7 @@ int qca_func_secure_check (const void *)
 class gcryptProvider : public QCA::Provider
 {
 public:
-    void init()
+    void init() override
     {
 	if (!gcry_control (GCRYCTL_ANY_INITIALIZATION_P))
 	{ /* No other library has already initialized libgcrypt. */
@@ -515,7 +520,7 @@ public:
 	    if (!gcry_check_version (GCRYPT_VERSION) )
 	    {
 		std::cout << "libgcrypt is too old (need " << GCRYPT_VERSION;
-		std::cout << ", have " << gcry_check_version(NULL) << ")" << std::endl;
+		std::cout << ", have " << gcry_check_version(nullptr) << ")" << std::endl;
 	    }
 	    gcry_set_allocation_handler (qca_func_malloc,
 					 qca_func_secure_malloc,
@@ -526,174 +531,168 @@ public:
 	}
     }
 
-    int qcaVersion() const
+    int qcaVersion() const override
     {
         return QCA_VERSION;
     }
 
-    QString name() const
+    QString name() const override
     {
-	return "qca-gcrypt";
+	return QStringLiteral("qca-gcrypt");
     }
 
-    QStringList features() const
+    QStringList features() const override
     {
 	QStringList list;
-	list += "sha1";
-	list += "md4";
-	list += "md5";
-	list += "ripemd160";
+	list += QStringLiteral("sha1");
+	list += QStringLiteral("md4");
+	list += QStringLiteral("md5");
+	list += QStringLiteral("ripemd160");
 #ifdef GCRY_MD_SHA224
-	list += "sha224";
+	list += QStringLiteral("sha224");
 #endif
-	list += "sha256";
-	list += "sha384";
-	list += "sha512";
-	list += "hmac(md5)";
-	list += "hmac(sha1)";
+	list += QStringLiteral("sha256");
+	list += QStringLiteral("sha384");
+	list += QStringLiteral("sha512");
+	list += QStringLiteral("hmac(md5)");
+	list += QStringLiteral("hmac(sha1)");
 #ifdef GCRY_MD_SHA224
-	list += "hmac(sha224)";
+	list += QStringLiteral("hmac(sha224)");
 #endif
-	list += "hmac(sha256)";
-	if ( ! ( NULL == gcry_check_version("1.3.0") ) ) {
+	list += QStringLiteral("hmac(sha256)");
+	if ( ! ( nullptr == gcry_check_version("1.3.0") ) ) {
 	    // 1.2 and earlier have broken implementation
-	    list += "hmac(sha384)";
-	    list += "hmac(sha512)";
+	    list += QStringLiteral("hmac(sha384)");
+	    list += QStringLiteral("hmac(sha512)");
 	}
-	list += "hmac(ripemd160)";
-	list += "aes128-ecb";
-	list += "aes128-cfb";
-	list += "aes128-cbc";
-	list += "aes192-ecb";
-	list += "aes192-cfb";
-	list += "aes192-cbc";
-	list += "aes256-ecb";
-	list += "aes256-cfb";
-	list += "aes256-cbc";
-	list += "blowfish-ecb";
-	list += "blowfish-cbc";
-	list += "blowfish-cfb";
-	list += "tripledes-ecb";
-	list += "des-ecb";
-	list += "des-cbc";
-	list += "des-cfb";
-	if ( ! ( NULL == gcry_check_version("1.3.0") ) ) {
+	list += QStringLiteral("hmac(ripemd160)");
+	list += QStringLiteral("aes128-ecb");
+	list += QStringLiteral("aes128-cfb");
+	list += QStringLiteral("aes128-cbc");
+	list += QStringLiteral("aes192-ecb");
+	list += QStringLiteral("aes192-cfb");
+	list += QStringLiteral("aes192-cbc");
+	list += QStringLiteral("aes256-ecb");
+	list += QStringLiteral("aes256-cfb");
+	list += QStringLiteral("aes256-cbc");
+	list += QStringLiteral("blowfish-ecb");
+	list += QStringLiteral("blowfish-cbc");
+	list += QStringLiteral("blowfish-cfb");
+	list += QStringLiteral("tripledes-ecb");
+// 	list += QStringLiteral("des-ecb");
+	list += QStringLiteral("des-cbc");
+	list += QStringLiteral("des-cfb");
+	if ( ! ( nullptr == gcry_check_version("1.3.0") ) ) {
 	    // 1.2 branch and earlier doesn't support OFB mode
-	    list += "aes128-ofb";
-	    list += "aes192-ofb";
-	    list += "aes256-ofb";
-	    list += "des-ofb";
-	    list += "tripledes-ofb";
-	    list += "blowfish-ofb";
+	    list += QStringLiteral("aes128-ofb");
+	    list += QStringLiteral("aes192-ofb");
+	    list += QStringLiteral("aes256-ofb");
+	    list += QStringLiteral("des-ofb");
+	    list += QStringLiteral("tripledes-ofb");
+	    list += QStringLiteral("blowfish-ofb");
 	}
-	list += "pbkdf1(sha1)";
-	list += "pbkdf2(sha1)";
+	list += QStringLiteral("pbkdf1(sha1)");
+	list += QStringLiteral("pbkdf2(sha1)");
 	return list;
     }
 
-    Context *createContext(const QString &type)
+    Context *createContext(const QString &type) override
     {
         // std::cout << "type: " << qPrintable(type) << std::endl;
-	if ( type == "sha1" )
+	if ( type == QLatin1String("sha1") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_SHA1, this, type );
-	else if ( type == "md4" )
+	else if ( type == QLatin1String("md4") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_MD4, this, type );
-	else if ( type == "md5" )
+	else if ( type == QLatin1String("md5") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_MD5, this, type );
-	else if ( type == "ripemd160" )
+	else if ( type == QLatin1String("ripemd160") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_RMD160, this, type );
 #ifdef GCRY_MD_SHA224
-	else if ( type == "sha224" )
+	else if ( type == QLatin1String("sha224") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_SHA224, this, type );
 #endif
-	else if ( type == "sha256" )
+	else if ( type == QLatin1String("sha256") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_SHA256, this, type );
-	else if ( type == "sha384" )
+	else if ( type == QLatin1String("sha384") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_SHA384, this, type );
-	else if ( type == "sha512" )
+	else if ( type == QLatin1String("sha512") )
 	    return new gcryptQCAPlugin::gcryHashContext( GCRY_MD_SHA512, this, type );
-	else if ( type == "hmac(md5)" )
+	else if ( type == QLatin1String("hmac(md5)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_MD5, this, type );
-	else if ( type == "hmac(sha1)" )
+	else if ( type == QLatin1String("hmac(sha1)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_SHA1, this, type );
 #ifdef GCRY_MD_SHA224
-	else if ( type == "hmac(sha224)" )
+	else if ( type == QLatin1String("hmac(sha224)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_SHA224, this, type );
 #endif
-	else if ( type == "hmac(sha256)" )
+	else if ( type == QLatin1String("hmac(sha256)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_SHA256, this, type );
-	else if ( type == "hmac(sha384)" )
+	else if ( type == QLatin1String("hmac(sha384)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_SHA384, this, type );
-	else if ( type == "hmac(sha512)" )
+	else if ( type == QLatin1String("hmac(sha512)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_SHA512, this, type );
-	else if ( type == "hmac(ripemd160)" )
+	else if ( type == QLatin1String("hmac(ripemd160)") )
 	    return new gcryptQCAPlugin::gcryHMACContext( GCRY_MD_RMD160, this, type );
-	else if ( type == "aes128-ecb" )
+	else if ( type == QLatin1String("aes128-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES128, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "aes128-cfb" )
+	else if ( type == QLatin1String("aes128-cfb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES128, GCRY_CIPHER_MODE_CFB, false, this, type );
-	else if ( type == "aes128-ofb" )
+	else if ( type == QLatin1String("aes128-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES128, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "aes128-cbc" )
+	else if ( type == QLatin1String("aes128-cbc") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES128, GCRY_CIPHER_MODE_CBC, false, this, type );
-	else if ( type == "aes192-ecb" )
+	else if ( type == QLatin1String("aes192-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES192, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "aes192-cfb" )
+	else if ( type == QLatin1String("aes192-cfb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES192, GCRY_CIPHER_MODE_CFB, false, this, type );
-	else if ( type == "aes192-ofb" )
+	else if ( type == QLatin1String("aes192-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES192, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "aes192-cbc" )
+	else if ( type == QLatin1String("aes192-cbc") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES192, GCRY_CIPHER_MODE_CBC, false, this, type );
-	else if ( type == "aes256-ecb" )
+	else if ( type == QLatin1String("aes256-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES256, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "aes256-cfb" )
+	else if ( type == QLatin1String("aes256-cfb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES256, GCRY_CIPHER_MODE_CFB, false, this, type );
-	else if ( type == "aes256-ofb" )
+	else if ( type == QLatin1String("aes256-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES256, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "aes256-cbc" )
+	else if ( type == QLatin1String("aes256-cbc") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_AES256, GCRY_CIPHER_MODE_CBC, false, this, type );
-	else if ( type == "blowfish-ecb" )
+	else if ( type == QLatin1String("blowfish-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "blowfish-cbc" )
+	else if ( type == QLatin1String("blowfish-cbc") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_MODE_CBC, false, this, type );
-	else if ( type == "blowfish-cfb" )
+	else if ( type == QLatin1String("blowfish-cfb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_MODE_CFB, false, this, type );
-	else if ( type == "blowfish-ofb" )
+	else if ( type == QLatin1String("blowfish-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "tripledes-ecb" )
+	else if ( type == QLatin1String("tripledes-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_3DES, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "tripledes-ofb" )
+	else if ( type == QLatin1String("tripledes-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_3DES, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "des-ecb" )
+	else if ( type == QLatin1String("des-ecb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_DES, GCRY_CIPHER_MODE_ECB, false, this, type );
-	else if ( type == "des-cbc" )
+	else if ( type == QLatin1String("des-cbc") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_DES, GCRY_CIPHER_MODE_CBC, false, this, type );
-	else if ( type == "des-cfb" )
+	else if ( type == QLatin1String("des-cfb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_DES, GCRY_CIPHER_MODE_CFB, false, this, type );
-	else if ( type == "des-ofb" )
+	else if ( type == QLatin1String("des-ofb") )
 	    return new gcryptQCAPlugin::gcryCipherContext( GCRY_CIPHER_DES, GCRY_CIPHER_MODE_OFB, false, this, type );
-	else if ( type == "pbkdf1(sha1)" )
+	else if ( type == QLatin1String("pbkdf1(sha1)") )
 	    return new gcryptQCAPlugin::pbkdf1Context( GCRY_MD_SHA1, this, type );
-	else if ( type == "pbkdf2(sha1)" )
+	else if ( type == QLatin1String("pbkdf2(sha1)") )
 	    return new gcryptQCAPlugin::pbkdf2Context( GCRY_MD_SHA1, this, type );
 	else
-	    return 0;
+	    return nullptr;
     }
 };
 
 class gcryptPlugin : public QObject, public QCAPlugin
 {
     Q_OBJECT
-#if QT_VERSION >= 0x050000
 	Q_PLUGIN_METADATA(IID "com.affinix.qca.Plugin/1.0")
-#endif
     Q_INTERFACES(QCAPlugin)
 	public:
-    virtual QCA::Provider *createProvider() { return new gcryptProvider; }
+    QCA::Provider *createProvider() override { return new gcryptProvider; }
 };
 
 #include "qca-gcrypt.moc"
-
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(qca_gcrypt, gcryptPlugin)
-#endif
