@@ -21,21 +21,20 @@
 
 using namespace QCA;
 
-namespace gpgQCAPlugin {
-
-MyKeyStoreEntry::MyKeyStoreEntry(const PGPKey &_pub, const PGPKey &_sec, Provider *p)
-    : KeyStoreEntryContext(p)
+namespace gpgQCAPlugin
 {
-    pub = _pub;
-    sec = _sec;
-    if (!sec.isNull())
-        item_type = KeyStoreEntry::TypePGPSecretKey;
-    else
-        item_type = KeyStoreEntry::TypePGPPublicKey;
+
+MyKeyStoreEntry::MyKeyStoreEntry(const PGPKey &_pub, const PGPKey &_sec, Provider *p) : KeyStoreEntryContext(p)
+{
+	pub = _pub;
+	sec = _sec;
+	if(!sec.isNull())
+		item_type = KeyStoreEntry::TypePGPSecretKey;
+	else
+		item_type = KeyStoreEntry::TypePGPPublicKey;
 }
 
-MyKeyStoreEntry::MyKeyStoreEntry(const MyKeyStoreEntry &from)
-    : KeyStoreEntryContext(from)
+MyKeyStoreEntry::MyKeyStoreEntry(const MyKeyStoreEntry &from) : KeyStoreEntryContext(from)
 {
 }
 
@@ -45,52 +44,52 @@ MyKeyStoreEntry::~MyKeyStoreEntry()
 
 Provider::Context *MyKeyStoreEntry::clone() const
 {
-    return new MyKeyStoreEntry(*this);
+	return new MyKeyStoreEntry(*this);
 }
 
 KeyStoreEntry::Type MyKeyStoreEntry::type() const
 {
-    return item_type;
+	return item_type;
 }
 
 QString MyKeyStoreEntry::name() const
 {
-    return pub.primaryUserId();
+	return pub.primaryUserId();
 }
 
 QString MyKeyStoreEntry::id() const
 {
-    return pub.keyId();
+	return pub.keyId();
 }
 
 QString MyKeyStoreEntry::storeId() const
 {
-    return _storeId;
+	return _storeId;
 }
 
 QString MyKeyStoreEntry::storeName() const
 {
-    return _storeName;
+	return _storeName;
 }
 
 PGPKey MyKeyStoreEntry::pgpSecretKey() const
 {
-    return sec;
+	return sec;
 }
 
 PGPKey MyKeyStoreEntry::pgpPublicKey() const
 {
-    return pub;
+	return pub;
 }
 
 QString MyKeyStoreEntry::serialize() const
 {
-    // we only serialize the key id.  this means the keyring
-    //   must be available to restore the data
-    QStringList out;
-    out += escape_string(QStringLiteral("qca-gnupg-1"));
-    out += escape_string(pub.keyId());
-    return out.join(QStringLiteral(":"));
+	// we only serialize the key id.  this means the keyring
+	//   must be available to restore the data
+	QStringList out;
+	out += escape_string(QStringLiteral("qca-gnupg-1"));
+	out += escape_string(pub.keyId());
+	return out.join(QStringLiteral(":"));
 }
 
 } // end namespace gpgQCAPlugin
