@@ -16,9 +16,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-#include "mykeystorelist.h"
-#include "myopenpgpcontext.h"
 #include "mypgpkeycontext.h"
+#include "myopenpgpcontext.h"
+#include "mykeystorelist.h"
 #include "qcaprovider.h"
 #include <QtPlugin>
 
@@ -27,52 +27,49 @@ using namespace gpgQCAPlugin;
 class gnupgProvider : public QCA::Provider
 {
 public:
-    void init() override
-    {
-    }
+	void init() override
+	{
+	}
 
-    int qcaVersion() const override
-    {
-        return QCA_VERSION;
-    }
+	int qcaVersion() const override
+	{
+		return QCA_VERSION;
+	}
 
-    QString name() const override
-    {
-        return QStringLiteral("qca-gnupg");
-    }
+	QString name() const override
+	{
+		return QStringLiteral("qca-gnupg");
+	}
 
-    QStringList features() const override
-    {
-        QStringList list;
-        list += QStringLiteral("pgpkey");
-        list += QStringLiteral("openpgp");
-        list += QStringLiteral("keystorelist");
-        return list;
-    }
+	QStringList features() const override
+	{
+		QStringList list;
+		list += QStringLiteral("pgpkey");
+		list += QStringLiteral("openpgp");
+		list += QStringLiteral("keystorelist");
+		return list;
+	}
 
-    Context *createContext(const QString &type) override
-    {
-        if (type == QLatin1String("pgpkey"))
-            return new MyPGPKeyContext(this);
-        else if (type == QLatin1String("openpgp"))
-            return new MyOpenPGPContext(this);
-        else if (type == QLatin1String("keystorelist"))
-            return new MyKeyStoreList(this);
-        else
-            return nullptr;
-    }
+	Context *createContext(const QString &type) override
+	{
+		if(type == QLatin1String("pgpkey"))
+			return new MyPGPKeyContext(this);
+		else if(type == QLatin1String("openpgp"))
+			return new MyOpenPGPContext(this);
+		else if(type == QLatin1String("keystorelist"))
+			return new MyKeyStoreList(this);
+		else
+			return nullptr;
+	}
 };
 
 class gnupgPlugin : public QObject, public QCAPlugin
 {
-    Q_OBJECT
-    Q_PLUGIN_METADATA(IID "com.affinix.qca.Plugin/1.0")
-    Q_INTERFACES(QCAPlugin)
+	Q_OBJECT
+	Q_PLUGIN_METADATA(IID "com.affinix.qca.Plugin/1.0")
+	Q_INTERFACES(QCAPlugin)
 public:
-    QCA::Provider *createProvider() override
-    {
-        return new gnupgProvider;
-    }
+	QCA::Provider *createProvider() override { return new gnupgProvider; }
 };
 
 #include "qca-gnupg.moc"
