@@ -365,7 +365,7 @@ bool isSupported(const QStringList &features, const QString &provider)
 
 bool isSupported(const char *features, const QString &provider)
 {
-	return isSupported(QString(features).split(',', QString::SkipEmptyParts), provider);
+	return isSupported(QString::fromLatin1(features).split(QLatin1Char(','), QString::SkipEmptyParts), provider);
 }
 
 QStringList supportedFeatures()
@@ -458,17 +458,17 @@ QStringList pluginPaths()
 {
 	QStringList paths;
 #ifndef DEVELOPER_MODE
-	const QString qcaPluginPath = qgetenv("QCA_PLUGIN_PATH");
+	const QByteArray qcaPluginPath = qgetenv("QCA_PLUGIN_PATH");
 	if (!qcaPluginPath.isEmpty())
 	{
 #ifdef Q_OS_WIN
-		QLatin1Char pathSep(';');
+		char pathSep(';');
 #else
-		QLatin1Char pathSep(':');
+		char pathSep(':');
 #endif
-		foreach (const QString &path, qcaPluginPath.split(pathSep))
+		foreach (const QByteArray &path, qcaPluginPath.split(pathSep))
 		{
-			QString canonicalPath = QDir(path).canonicalPath();
+			const QString canonicalPath = QDir(QFile::decodeName(path)).canonicalPath();
 			if (!canonicalPath.isEmpty())
 				paths << canonicalPath;
 		}
@@ -567,12 +567,12 @@ static QVariantMap readConfig(const QString &name)
 {
 	QSettings settings(QStringLiteral("Affinix"), QStringLiteral("QCA2"));
 	settings.beginGroup(QStringLiteral("ProviderConfig"));
-	QStringList providerNames = settings.value(QStringLiteral("providerNames")).toStringList();
+	const QStringList providerNames = settings.value(QStringLiteral("providerNames")).toStringList();
 	if(!providerNames.contains(name))
 		return QVariantMap();
 
 	settings.beginGroup(name);
-	QStringList keys = settings.childKeys();
+	const QStringList keys = settings.childKeys();
 	QVariantMap map;
 	foreach(const QString &key, keys)
 		map[key] = settings.value(key);
@@ -651,7 +651,7 @@ QVariantMap getProviderConfig(const QString &name)
 	Provider *p = findProvider(name);
 	if(!p)
 		return conf;
-	QVariantMap pconf = p->defaultConfig();
+	const QVariantMap pconf = p->defaultConfig();
 	if(!configIsValid(pconf))
 		return conf;
 
@@ -685,7 +685,7 @@ void saveProviderConfig(const QString &name)
 QVariantMap getProviderConfig_internal(Provider *p)
 {
 	QVariantMap conf;
-	QString name = p->name();
+	const QString name = p->name();
 
 	global->config_mutex.lock();
 
@@ -700,7 +700,7 @@ QVariantMap getProviderConfig_internal(Provider *p)
 
 	// if provider doesn't exist or doesn't have a valid config form,
 	//   use the config we loaded
-	QVariantMap pconf = p->defaultConfig();
+	const QVariantMap pconf = p->defaultConfig();
 	if(!configIsValid(pconf))
 		return conf;
 
@@ -742,7 +742,7 @@ bool haveSystemStore()
 	KeyStoreManager ksm;
 	ksm.waitForBusyFinished();
 
-	QStringList list = ksm.keyStores();
+	const QStringList list = ksm.keyStores();
 	for(int n = 0; n < list.count(); ++n)
 	{
 		KeyStore ks(list[n], &ksm);
@@ -760,7 +760,7 @@ CertificateCollection systemStore()
 	ksm.waitForBusyFinished();
 
 	CertificateCollection col;
-	QStringList list = ksm.keyStores();
+	const QStringList list = ksm.keyStores();
 	for(int n = 0; n < list.count(); ++n)
 	{
 		KeyStore ks(list[n], &ksm);
@@ -769,7 +769,7 @@ CertificateCollection systemStore()
 		if(ks.type() == KeyStore::System && ks.holdsTrustedCertificates())
 		{
 			// extract contents
-			QList<KeyStoreEntry> entries = ks.entryList();
+			const QList<KeyStoreEntry> entries = ks.entryList();
 			for(int i = 0; i < entries.count(); ++i)
 			{
 				if(entries[i].type() == KeyStoreEntry::TypeCertificate)
@@ -1270,7 +1270,7 @@ MemoryRegion Filter::process(const MemoryRegion &a)
 	MemoryRegion buf = update(a);
 	if(!ok())
 		return MemoryRegion();
-	MemoryRegion fin = final();
+	const MemoryRegion fin = final();
 	if(!ok())
 		return MemoryRegion();
 	if(buf.isSecure() || fin.isSecure())
@@ -1835,7 +1835,7 @@ void handler_remove(HandlerBase *h)
 	if(at == -1)
 		return;
 
-	QList<int> ids = g_event->handlers[at].ids;
+	const QList<int> ids = g_event->handlers[at].ids;
 	g_event->handlers.removeAt(at);
 
 	// adjust handler positions within askers
@@ -1928,7 +1928,7 @@ bool asker_ask(AskerBase *a, const Event &e)
 	i.event = e;
 	i.handler_pos = pos;
 	g_event->askers += i;
-	int asker_at = g_event->askers.count() - 1;
+	const int asker_at = g_event->askers.count() - 1;
 
 	g_event->ask(asker_at);
 	return true;
