@@ -779,13 +779,13 @@ static QString escape_string(const QString &in)
 	QString out;
 	for(const QChar &c : in)
 	{
-		if(c == '\\')
+		if(c == QLatin1Char('\\'))
 			out += QLatin1String("\\\\");
-		else if(c == ':')
+		else if(c == QLatin1Char(':'))
 			out += QLatin1String("\\c");
-		else if(c == ',')
+		else if(c == QLatin1Char(','))
 			out += QLatin1String("\\o");
-		else if(c == '\n')
+		else if(c == QLatin1Char('\n'))
 			out += QLatin1String("\\n");
 		else
 			out += c;
@@ -798,19 +798,19 @@ static bool unescape_string(const QString &in, QString *_out)
 	QString out;
 	for(int n = 0; n < in.length(); ++n)
 	{
-		if(in[n] == '\\')
+		if(in[n] == QLatin1Char('\\'))
 		{
 			if(n + 1 >= in.length())
 				return false;
 
-			if(in[n + 1] == '\\')
-				out += '\\';
-			else if(in[n + 1] == 'c')
-				out += ':';
-			else if(in[n + 1] == 'o')
-				out += ',';
-			else if(in[n + 1] == 'n')
-				out += '\n';
+			if(in[n + 1] == QLatin1Char('\\'))
+				out += QLatin1Char('\\');
+			else if(in[n + 1] == QLatin1Char('c'))
+				out += QLatin1Char(':');
+			else if(in[n + 1] == QLatin1Char('o'))
+				out += QLatin1Char(',');
+			else if(in[n + 1] == QLatin1Char('n'))
+				out += QLatin1Char('\n');
 			else
 				return false;
 			++n;
@@ -833,7 +833,7 @@ static QString escape_stringlist(const QStringList &in)
 static bool unescape_stringlist(const QString &in, QStringList *_out)
 {
 	QStringList out;
-	QStringList list = in.split(':');
+	const QStringList list = in.split(QLatin1Char(':'));
 	for(int n = 0; n < list.count(); ++n)
 	{
 		QString str;
@@ -980,7 +980,7 @@ public:
 
 		if(entry_deserialize(in, &storeId, &storeName, &id, &name, &typestr, &datastr))
 		{
-			QByteArray data = Base64().stringToArray(datastr).toByteArray();
+			const QByteArray data = Base64().stringToArray(datastr).toByteArray();
 			DefaultKeyStoreEntry *c;
 
 			if(typestr == QLatin1String("cert"))
@@ -1125,7 +1125,7 @@ public:
 			crls += col.crls();
 		}
 
-		QString roots = shared->roots_file();
+		const QString roots = shared->roots_file();
 		if(!roots.isEmpty())
 		{
 			CertificateCollection col = CertificateCollection::fromFlatTextFile(roots);
@@ -1134,7 +1134,7 @@ public:
 		}
 
 #ifdef FRIENDLY_NAMES
-		QStringList names = makeFriendlyNames(certs);
+		const QStringList names = makeFriendlyNames(certs);
 #endif
 		for(int n = 0; n < certs.count(); ++n)
 		{
@@ -1171,7 +1171,7 @@ public:
 static bool unescape_config_stringlist(const QString &in, QStringList *_out)
 {
 	QStringList out;
-	QStringList list = in.split(',');
+	const QStringList list = in.split(QLatin1Char(','));
 	for(int n = 0; n < list.count(); ++n)
 	{
 		QString str;
@@ -1190,10 +1190,10 @@ public:
 
 	void init() override
 	{
-		QDateTime now = QDateTime::currentDateTime();
+		const QDateTime now = QDateTime::currentDateTime();
 
 		uint t = now.toTime_t();
-	        if(now.time().msec() > 0)
+		if(now.time().msec() > 0)
 			t /= now.time().msec();
 		qsrand(t);
 	}
@@ -1240,7 +1240,7 @@ public:
 	QVariantMap defaultConfig() const override
 	{
 		QVariantMap config;
-		config[QStringLiteral("formtype")] = "http://affinix.com/qca/forms/default#1.0";
+		config[QStringLiteral("formtype")] = QStringLiteral("http://affinix.com/qca/forms/default#1.0");
 		config[QStringLiteral("use_system")] = true;
 		config[QStringLiteral("roots_file")] = QString();
 		config[QStringLiteral("skip_plugins")] = QString();
@@ -1250,10 +1250,10 @@ public:
 
 	void configChanged(const QVariantMap &config) override
 	{
-		bool use_system = config[QStringLiteral("use_system")].toBool();
-		QString roots_file = config[QStringLiteral("roots_file")].toString();
-		QString skip_plugins_str = config[QStringLiteral("skip_plugins")].toString();
-		QString plugin_priorities_str = config[QStringLiteral("plugin_priorities")].toString();
+		const bool use_system = config[QStringLiteral("use_system")].toBool();
+		const QString roots_file = config[QStringLiteral("roots_file")].toString();
+		const QString skip_plugins_str = config[QStringLiteral("skip_plugins")].toString();
+		const QString plugin_priorities_str = config[QStringLiteral("plugin_priorities")].toString();
 
 		QStringList tmp;
 
@@ -1270,7 +1270,7 @@ public:
 			QString &s = plugin_priorities[n];
 
 			// make sure the entry ends with ":number"
-			int x = s.indexOf(':');
+			int x = s.indexOf(QLatin1Char(':'));
 			bool ok = false;
 			if(x != -1)
 				s.midRef(x + 1).toInt(&ok);
