@@ -314,7 +314,7 @@ QList<T> getList(const QString &provider)
 		ProviderList pl = allProviders();
 		for(int n = 0; n < pl.count(); ++n)
 		{
-			QList<T> other = G::getList(pl[n]);
+			const QList<T> other = G::getList(pl[n]);
 			for(int k = 0; k < other.count(); ++k)
 			{
 				// only add what we don't have in the list
@@ -446,12 +446,12 @@ QByteArray get_hash_id(const QString &name)
 
 QByteArray emsa3Encode(const QString &hashName, const QByteArray &digest, int size)
 {
-	QByteArray hash_id = get_hash_id(hashName);
+	const QByteArray hash_id = get_hash_id(hashName);
 	if(hash_id.isEmpty())
 		return QByteArray();
 
 	// logic adapted from Botan
-	int basesize = hash_id.size() + digest.size() + 2;
+	const int basesize = hash_id.size() + digest.size() + 2;
 	if(size == -1)
 		size = basesize + 1; // default to 1-byte pad
 	int padlen = size - basesize;
