@@ -126,18 +126,10 @@ private Q_SLOTS:
     void testDetachedSign();
     void testSignaturesWithExpiredSubkeys();
     void testEncryptionWithExpiredSubkeys();
-private:
-    QCA::Initializer* m_init;
 };
 
 void PgpUnitTest::initTestCase()
 {
-    // instead of initializing qca once, we will initialize it for every
-    //   test case.  this is the only way to get the keystore subsystem
-    //   to reload, which we need to do if we want qca-gnupg to respect
-    //   changes to $GNUPGHOME.
-    //m_init = new QCA::Initializer;
-
     // Change current directory to executable directory
     // it is need to find keys*_work directories
     if (!QCoreApplication::applicationDirPath().isEmpty())
@@ -146,7 +138,6 @@ void PgpUnitTest::initTestCase()
 
 void PgpUnitTest::cleanupTestCase()
 {
-    //delete m_init;
 }
 
 void PgpUnitTest::testKeyRing()
@@ -471,7 +462,7 @@ void PgpUnitTest::testClearsign()
 	if(msg2.success()) {
 	    // The trimmed() call is needed because clearsigning
 	    // trashes whitespace
-	    QCOMPARE( QString(msg2.read()).trimmed(), QString(plain).trimmed() );
+	    QCOMPARE( msg2.read().trimmed(), plain.trimmed() );
 	} else {
 	    qDebug() << "Failure:" <<  msg2.errorCode();
 	    QFAIL("Failed to verify clearsigned message");
@@ -682,7 +673,7 @@ void PgpUnitTest::testSignaturesWithExpiredSubkeys()
 		QByteArray signedResult = msg1.read();
 
 		QVERIFY(msg1.verifySuccess());
-		QCOMPARE(QString(signedResult).trimmed(), QString(validMessage).trimmed());
+		QCOMPARE(signedResult.trimmed(), validMessage.trimmed());
 
 		// Test signature made by the expired subkey
 		QByteArray expiredKeySignature("-----BEGIN PGP SIGNED MESSAGE-----\n"
